//---------------------------------------------------------------- -o--
// GTTestParseOfSection2.java 
// 
// Test error output of parse logic for Section2 of a Galactic Transaction.
//
// 
// HELPER METHODS--
//   generateOutputFileResults
//   tearDown
//
// TEST METHODS--
//   testSection2_misingTokensFirstHalf
//   testSection2_malformedGN
//   testSection2_missingTokensSecondHalf
//   testSection2_badAN
//   testSection2_missingWholeSection
//

import java.lang.*;
import java.io.*;
import java.util.*;

import junit.framework.*;
import org.junit.*;
import org.apache.commons.io.*;
import org.hamcrest.*;



//----------------------------------------------------------------- -o--
public class GTTestParseOfSection2 extends TestCase
{
  //-------------------------------------------------------------- -o--
  // Helper methods.
  //

  //------------------------------ -o-
  private String  generateOutputFileResults(String inputFileName)
  {
    String  outputFileFullPathname = null;

    File    outputResultsFile  = null;
    String  outputResults      = null;


    try {
      outputFileFullPathname  = GTHelper.setFilesAndRunProgram(inputFileName);
      outputResultsFile       = new File(outputFileFullPathname);

      assertTrue( 
          "Output file EXISTS.  ("+ outputResultsFile.getName() +")", 
          outputResultsFile.exists() );

      outputResults = 
          new String(FileUtils.readFileToString(outputResultsFile, "utf-8"));


    } catch (Exception e) {
      System.err.println("TEST ERROR IN "+ getClass() +": "+ e.toString());
    }


    return outputResults;

  } // generateOutputFileResults()



  //-------------------------------------------------------------- -o--
  // Test methods.
  //

  //------------------------------ -o-
  @After
  protected void  tearDown()
  {
    GalacticNumber.clear();
    MaterialUnit.clear();
  }


  //------------------------------ -o-
  @org.junit.Test
  public void  testSection2_misingTokensFirstHalf()
  {
    String  inputFileName  = 
                "section2-shouldFail-missingTokensFirstHalf-input.txt";
    String  outputResults  = generateOutputFileResults(inputFileName);


    String   expectedString       = 
                GTHelper.BADINPUT_PREFIX + "Titanium is 1032 Credits";

    Boolean  foundExpectedString  = 
                GTHelper.stringContains(outputResults, expectedString);

    if (!foundExpectedString) {
      GTHelper.dumpResultsString(outputResults, inputFileName);
    }

    assertTrue( 
      "FOUND expected string '"+ expectedString +"'.", foundExpectedString );

  } // testSection2_misingTokensFirstHalf()


  //------------------------------ -o-
  @org.junit.Test
  public void  testSection2_malformedGN()
  {
    String  inputFileName  = "section2-shouldFail-malformedGN-input.txt";
    String  outputResults  = generateOutputFileResults(inputFileName);


    String   expectedString       = 
                GTHelper.BADINPUT_PREFIX + "gagisoa Adamantium is 74 Credits";
    Boolean  foundExpectedString  = 
                GTHelper.stringContains(outputResults, expectedString);

    if (!foundExpectedString) {
      GTHelper.dumpResultsString(outputResults, inputFileName);
    }

    assertTrue( 
      "FOUND expected string '"+ expectedString +"'.", foundExpectedString );

  } // testSection2_malformedGN()


  //------------------------------ -o-
  @org.junit.Test
  public void  testSection2_missingTokensSecondHalf()
  {
    String  inputFileName  = 
                "section2-shouldFail-missingTokensSecondHalf-input.txt";
    String  outputResults  = generateOutputFileResults(inputFileName);


    String   expectedString       = 
                GTHelper.BADINPUT_PREFIX
		  + "kqve bead isoa reos Titanium is Credits";
    Boolean  foundExpectedString  = 
                GTHelper.stringContains(outputResults, expectedString);

    if (!foundExpectedString) {
      GTHelper.dumpResultsString(outputResults, inputFileName);
    }

    assertTrue( 
      "FOUND expected string '"+ expectedString +"'.", foundExpectedString );

  } // testSection2_missingTokensSecondHalf()


  //------------------------------ -o-
  @org.junit.Test
  public void  testSection2_badAN()
  {
    String  inputFileName  = "section2-shouldFail-badAN-input.txt";
    String  outputResults  = generateOutputFileResults(inputFileName);


    String   expectedString       = 
    		GTHelper.BADINPUT_PREFIX 
		  + "dupb dupb evoi kqve reos bead Copper is deadbeef Credits";
    Boolean  foundExpectedString  = 
                GTHelper.stringContains(outputResults, expectedString);

    if (!foundExpectedString) {
      GTHelper.dumpResultsString(outputResults, inputFileName);
    }

    assertTrue( 
      "FOUND expected string '"+ expectedString +"'.", foundExpectedString );

  } // testSection2_badAN()


  //------------------------------ -o-
  @org.junit.Test
  public void  testSection2_missingWholeSection()
  {
    String  inputFileName  = 
    		"section2-shouldFail-missingWholeSection-input.txt";
    String  outputResults  = generateOutputFileResults(inputFileName);


    String   expectedString       = 
    		GTHelper.BADINPUT_PREFIX + "how many Credits is zoew Zircon";
    Boolean  foundExpectedString  = 
                GTHelper.stringContains(outputResults, expectedString);

    if (!foundExpectedString) {
      GTHelper.dumpResultsString(outputResults, inputFileName);
    }

    assertTrue( 
      "FOUND expected string '"+ expectedString +"'.", foundExpectedString );

  } // testSection2_missingWholeSection()


} // class GTTestParseOfSection2

