//---------------------------------------------------------------- -o--
// GalacticNumeralTest.java 
// 
// HELPER METHODS--
//   setUp
//   tearDown
//
// TEST METHODS--
//   testInvalidGalacticNumeralExpressions
//   testValidGalacticNumeralExpressions
//
//
// @version 0.1 
//

import java.lang.*;
import java.io.*;
import java.util.*;

import junit.framework.*;
import org.junit.*;
import org.apache.commons.io.*;
import org.hamcrest.*;



//----------------------------------------------------------------- -o--
public class GalacticNumeralTest extends TestCase
{
  HashMap<String, String>  gn2rn;    // map GalacticNumber's -> RomanNumber's



  //-------------------------------------------------------------- -o--
  // Test methods.
  //

  //------------------------------ -o-
  @Before
  protected void  setUp()  throws GTException
  {
    // Populate GalacticNumber map with valid entries.
    //
    gn2rn = new HashMap<String, String>();

    gn2rn.put("pith", "M");
    gn2rn.put("jara", "D");
    gn2rn.put("kroa", "C");
    gn2rn.put("soam", "L");
    gn2rn.put("dala", "X");
    gn2rn.put("zila", "V");
    gn2rn.put("gepk", "I");

    for (String rnKey : gn2rn.keySet()) {
      try {
	//new GalacticNumber(rnKey, gn2rn.get(rnKey));
	GalacticNumber.mapFromRomanNumber(rnKey, gn2rn.get(rnKey));
      } catch (GTException e) {
        throw new GTException(
	  "TEST ERROR IN "+ getClass() +": GalacticNumber failed.");
      }
    }

  } // setUp()


  //------------------------------ -o-
  @After
  protected void  tearDown()
  {
    GalacticNumber.clear();

    gn2rn.clear();
    gn2rn = null;
  }


  //------------------------------ -o-
  @org.junit.Test
  public void  testInvalidGalacticNumeralExpressions()
  {
    HashSet<String>  gnExpressionSet    = new HashSet<String>();
    Boolean          constructorFailed  = false;

    gnExpressionSet.add(null);                              // range cases
    gnExpressionSet.add("");

    gnExpressionSet.add("pith jara nokeyforthisone");       // invalid keys

    gnExpressionSet.add("kroa dala kroa dala soam");        // bad RomanNumerals
    gnExpressionSet.add("kroa dala kroa soam dala dala dala"); 
    gnExpressionSet.add("kroa jara kroa");       


    //
    Iterator<String>  gnIter = gnExpressionSet.iterator(); 

    while (gnIter.hasNext()) 
    {
      String  galacticNumeral = gnIter.next();

      try {
        constructorFailed = false;
        new GalacticNumeral(galacticNumeral);

      } catch (GTException e) {
        constructorFailed = true;
      }

      assertTrue(
        "Constructor for GalacticNumber("+ galacticNumeral +") has FAILED.",
        constructorFailed );

    } // endwhile

  } // testInvalidGalacticNumeralExpressions()


  //------------------------------ -o-
  @org.junit.Test
  public void  testValidGalacticNumeralExpressions()
  {
    Boolean  constructorSucceeded  = false;

    HashMap<String, Float>  gnExpressionMap = new HashMap<String, Float>();

    gnExpressionMap.put("pith",                           new Float(1000));
    gnExpressionMap.put("pith kroa pith dala kroa",       new Float(1990));
    gnExpressionMap.put("pith jara kroa soam dala gepk",  new Float(1661));
    gnExpressionMap.put("pith pith jara kroa",            new Float(2600));

    
    //
    for (String gnKey : gnExpressionMap.keySet())
    {
      String  galacticNumeral  = gnKey;
      Float   gnValue          = gnExpressionMap.get(gnKey);
      Float   arabicNumeral    = new Float(-1);

      constructorSucceeded = false;
      try {
        GalacticNumeral  gn = new GalacticNumeral(galacticNumeral);
	arabicNumeral = gn.asArabicNumeral();

        constructorSucceeded = true;

      } catch (GTException e) {
        constructorSucceeded = false;
      }

      assertTrue(
        "GalacticNumber("+ galacticNumeral +") EQUALS "+ gnValue +".",
        constructorSucceeded && (gnValue.equals(arabicNumeral)) );

    } // endwhile

  } // testValidGalacticNumeralExpressions()


} // class GalacticNumeralTest

