//---------------------------------------------------------------- -o--
// RomanNumeralTest.java 
// 
// Test parse of Roman Numeral strings -- rejecting improperly formed
//   strings and returning correct value for properly formed strings. 
//
//
// TEST METHODS--
//   testValidExpressions
//   testInvalidExpressions
//
//
// @version 0.1
//

import java.lang.*;
import java.io.*;
import java.util.*;

import junit.framework.*;
import org.junit.*;
import org.apache.commons.io.*;
import org.hamcrest.*;



//----------------------------------------------------------------- -o--
public class RomanNumeralTest extends TestCase
{
  //-------------------------------------------------------------- -o--
  // Test methods.
  //

  //------------------------------ -o-
  @org.junit.Test
  public void  testValidExpressions()
  {
    HashMap<String, Float>  rnStringAndValueMap = 
                                        new HashMap<String, Float>();

    rnStringAndValueMap.put("CM",               new Float(900));
    rnStringAndValueMap.put("DCD",              new Float(900));
    rnStringAndValueMap.put("LXL",              new Float(90));
    rnStringAndValueMap.put("M",                new Float(1000));
    rnStringAndValueMap.put("MCMXC",            new Float(1990));
    rnStringAndValueMap.put("MDCLXI",           new Float(1661));
    rnStringAndValueMap.put("MMDC",             new Float(2600));
    rnStringAndValueMap.put("MMM",              new Float(3000));
    rnStringAndValueMap.put("MMMCMXCIX",        new Float(3999));
    rnStringAndValueMap.put("MMMDCCCLXXXVIII",  new Float(3888));
    rnStringAndValueMap.put("XC",               new Float(90));


    //
    for (String rnKey : rnStringAndValueMap.keySet())
    {
      RomanNumeral  rn = null;
      Float         rnValue;

      Boolean       constructorSucceeded = false;

      try {
        rn = new RomanNumeral(rnKey);
        constructorSucceeded = true;
      } catch (GTException e) {
        // EMPTY
      }

      rnValue = rnStringAndValueMap.get(rnKey);

      assertTrue(
        "Constructor for RomanNumeral(\""+ rnKey +"\") is SUCCESSFUL.",
        constructorSucceeded );

      assertTrue(
        "RomanNumeral "+ rnKey +" IS EQUAL to "+ rnValue +".",
        rnValue.equals(rn.asArabicNumeral()) );

    } // endfor

  } // testValidExpressions()


  //------------------------------ -o-
  @org.junit.Test
  public void  testInvalidExpressions()
  {
    HashSet<String>  rnStringSet = new HashSet<String>();

    rnStringSet.add(null);
    rnStringSet.add("");
    rnStringSet.add("CDC");
    rnStringSet.add("CXCLXXX");
    rnStringSet.add("CXCXL");
    rnStringSet.add("MCMCDCCC");
    rnStringSet.add("MMMCMDCCCXCLXXXIXVIII");
    rnStringSet.add("MMMM");


    //
    Iterator<String>  rnIter  = rnStringSet.iterator();

    while (rnIter.hasNext())
    {
      RomanNumeral  rn     = null;
      String        rnKey  = rnIter.next();

      Boolean       constructorFailed = false;

      try {
        rn = new RomanNumeral(rnKey);
      } catch (GTException e) {
	constructorFailed = true;
      }

      assertTrue(
        "Constructor for RomanNumeral(\""+ rnKey +"\") HAS FAILED.",
        constructorFailed );

    } // endfor

  } // testInvalidExpressions()


} // class RomanNumeralTest

